#
# spec file for package gnome-terminal
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-terminal
Version:        3.20.2
Release:        3.2
Summary:        GNOME Terminal
License:        GPL-3.0+ and LGPL-2.1+
Group:          System/X11/Terminals
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/gnome-terminal/3.20/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM gnome-terminal-resize-fix.patch bgo#760944 zaitor@opensuse.org -- Fix resizing of gnome-terminal, patches from upstream bug.
Patch0:         gnome-terminal-resize-fix.patch
# PATCH-FIX-UPSTREAM gnome-terminal-profile-editor-initialize-palette.patch bgo#768850 zaitor@opensuse.org -- profile: editor: Properly initialize the first palette color
Patch1:         gnome-terminal-profile-editor-initialize-palette.patch
# PATCH-FIX-UPSTREAM gnome-terminal-notebook-avoid-crash-on-tab-DND.patch bgo#769161 zaitor@opensuse.org -- notebook: avoid crash on tab DND
Patch2:         gnome-terminal-notebook-avoid-crash-on-tab-DND.patch
BuildRequires:  fdupes
# Needed for search provider. It should not be needed in my opionion, we have to take this up with upstream, or just provide search provider interface definition file as source.
BuildRequires:  gnome-shell
BuildRequires:  intltool >= 0.50.0
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.26
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(dconf) >= 0.12.0
%if 0%{?sle_version}
BuildRequires:  pkgconfig(gconf-2.0) >= 2.31.3
%endif
BuildRequires:  pkgconfig(gio-2.0) >= 2.34.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.19.8
BuildRequires:  pkgconfig(libnautilus-extension) >= 3.0.0
# Temp disabled as pcre support in vte got disabled, NB when reenabling, make sure to remove --without-pcre2 from configure.
#BuildRequires:  pkgconfig(libpcre2-8) >= 10.00
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vte-2.91) >= 0.44.2
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  filesystem
%if 0%{?sle_version}
Requires(pre):  gconf2
%endif

%description
This package provides the GNOME terminal emulator application.

%package -n gnome-shell-search-provider-gnome-terminal
Summary:        GNOME Terminal -- Search Provider for GNOME Shell
Group:          System/X11/Terminals
Supplements:    packageand(gnome-shell:%{name})
Requires:       %{name} = %{version}

%description -n gnome-shell-search-provider-gnome-terminal
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Terminal.

%package -n nautilus-extension-terminal
Summary:        Nautilus Extension to Open Terminal in Folders
Group:          System/GUI/GNOME
Supplements:    packageand(nautilus:%{name})
# nautilus-open-terminal was merged into gnome-terminal source during 3.9 development.
Provides:       nautilus-open-terminal = %{version}
Obsoletes:      nautilus-open-terminal < %{version}

%description -n nautilus-extension-terminal
This is a nautilus extension that allows you to open a terminal in
arbitrary folders.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
translation-update-upstream

%build
%configure \
    --disable-static \
    --without-pcre2 \
%if !0%{?sle_version}
    --disable-migration \
%endif
    --with-gtk=3.0 \
    --with-nautilus-extension
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print
%suse_update_desktop_file org.gnome.Terminal
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post
%glib2_gsettings_schema_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun

%files
%defattr (-, root, root)
%doc AUTHORS COPYING ChangeLog NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/gnome-terminal
%dir %{_datadir}/appdata
%{_datadir}/appdata/org.gnome.Terminal.appdata.xml
%{_datadir}/applications/org.gnome.Terminal.desktop
%{_libexecdir}/gnome-terminal-server
%if 0%{?sle_version}
%{_libexecdir}/gnome-terminal-migration
%endif
%{_datadir}/dbus-1/services/org.gnome.Terminal.service
%{_datadir}/glib-2.0/schemas/org.gnome.Terminal.gschema.xml
%{_userunitdir}/gnome-terminal-server.service

%files -n gnome-shell-search-provider-gnome-terminal
%defattr (-, root, root)
%{_datadir}/gnome-shell/search-providers/gnome-terminal-search-provider.ini

%files -n nautilus-extension-terminal
%defattr(-,root,root)
%{_libdir}/nautilus/extensions-3.0/libterminal-nautilus.so
%{_datadir}/appdata/org.gnome.Terminal.Nautilus.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Jul 25 2016 zaitor@opensuse.org
- Add gnome-terminal-notebook-avoid-crash-on-tab-DND.patch and
  gnome-terminal-profile-editor-initialize-palette.patch: Two
  cherrypicked bugfix commits from upstream stable branch
  (bgo#768850, bgo#769161, boo#980474).
* Thu Jul 21 2016 fcrozat@suse.com
- Update gnome-terminal-resize-fix.patch with latest revision of
  the patches, still not accepted upstream (bgo#760944 bsc#987859).
* Tue May 24 2016 zaitor@opensuse.org
- Add gnome-terminal-resize-fix.patch: Fix resizing of
  gnome-terminal, patches from upstream bug (bgo#760944).
* Tue May 24 2016 mgorse@suse.com
- Remove gnome-core obsoletes; it is from 2002 or so and not
  relevant now.
* Thu May 19 2016 zaitor@opensuse.org
- Drop gnome-terminal-transparency-fix-for-broken-themes.patch and
  gnome-terminal-transparency.patch: We will not be bringing these
  back into the package as they brought various issues, and we do
  not want to chase upstreams releases for rebaseing.
- Following the above: Drop libtool BuildRequires and disabled
  autreconf call: no longer needed since the patch needing it in
  the past is already dropped.
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Thu May 12 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + server: Add a systemd user service (bgo#759115).
  + window:
  - Fix relief on tab menu button.
  - Set widget CSS name.
  + nautilus: Fix handing sftp folders with %% character.
  + Fix GSettings default value translations.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop 0001-build-Add-cleanup-functions.patch,
  0001-all-Do-not-use-s-format-with-g_variant_get.patch,
  0001-profile-Fix-dummy-settings-patch.patch,
  0001-utils-Fix-double-free-in-error-path.patch: fixed upstream.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + l10n: Mark a string for translation (bgo#763911).
  + Updated translations.
* Sat Mar 19 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Mar  1 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Bugs fixed: bgo#732128, bgo#734875, bgo#747316, bgo#756038,
    rh#1310892.
  + Updated translations.
* Thu Feb 18 2016 zaitor@opensuse.org
- Due to pcre2 support beeing disabled in vte, disable
  pkconfig(pcre-2.8) BuildRequires, and pass --without-pcre2 to
  configure.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + search: Revert to using a window instead of a popover.
  + profile:
  - Increase maximum of default column prefs.
  - Don't compare alpha colour components.
  - Add cursor colour prefs.
  - editor:
    . Add highlight colour prefs.
    . Make it clearer what the colour pickers select.
    . Don't compare alpha colour components.
    . Unset colour alpha component.
    . Add cursor colour prefs.
    . Try to fix the UI file.
    . Use new show-editor property on GtkColorButton.
  + client:
  - legacy:
    . Reimplement deprecated --title option.
    . --geometry option is unsupported on gtk+ >= 3.19.5.
  + window: Try again to find and fix a clipboard related crash.
  + util:
    . Fix compilation error in previous commit.
    . Unset colour alpha component.
  + screen: Don't use extra colours when using theme colors.
  + Add more appdata.
  + Updated translations.
* Fri Feb 12 2016 zaitor@opensuse.org
- Add pkgconfig(libpcre2-8) BuildRequires and stop passing
  - -without-pcre2 to configure.
- Alter how we run %%suse_update_desktop_file macro, upstream now
  ships a correct .desktop file.
- Drop disabled patch gnome-terminal-dark-theme.patch: Dark theme
  restored upstream, so no longer needed.
* Fri Feb 12 2016 dimstar@opensuse.org
- Update to version 3.19.2:
  + Bugs fixed: bgo#711059, bgo#755825, bgo#757314, bgo#757512.
  + Updated translations.
- Drop appdata-tools BuildRequires: validating the appdata's
  validity is upstreams task.
* Mon Dec 21 2015 fcrozat@suse.com
- Drop BuildRequires(gtk-2.0), we don't need gtk-builder-convert
  anymore.
- Enable back gconf2 migration code when building package for SLE
  and disable gconf2 BuildRequires when building for openSUSE.
* Mon Nov 23 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Updated translations.
- Pass --without-pcre2 to configure, we are missing it in openSUSE
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Fri Oct 30 2015 zaitor@opensuse.org
- Drop gconf2 Requires(pre), and pass --disable-migration to
  configure. We do not expect any holdouts to migrate any longer.
- Stop running autoreconf as patches are already disabled.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + notebook: Don't change show-tabs when going to empty notebook.
  + window:
  - Exit early from screen-removed handler for now empty
    notebook.
  - Pass tab switching keys to the terminal for tabless windows.
  + profile: editor: Make colour buttons show their dialogue in
    editor mode.
  + i18n: Fix and mark incorrectly translated string as fuzzy.
  + server: Use distinct exit code for gtk_init failure.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Profile: Only use dconf when the settings backend is dconf.
  + Updated translations.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + build:
  - Don't include empty CSS.
  - Include missing terminal.common.css in tarballs.
  + Update translations.
- Rebase gnome-terminal-dark-theme.patch and
  gnome-terminal-transparency.patch, but do not yet apply them
  (there are some behavioural errors with them at the moment).
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + window:
  - Move tabs menu into an arrow button on the notebook
    (bgo#745329).
  - Add new tab button to notebook action area (bgo#138020).
  - Attach popup menus to their parent widgets (bgo#750755).
  + notebook:
  - Add API to create a box for the action buttons.
  - Add pref to always show tabs bar.
  - Add API to set the tab policy when to show the tabs bar.
  + widgets: Remove close button CSS.
  + app:
  - Add CSS loading infrastructure.
  - Let GtkApplication load the app menu automatically
    (bgo#734791).
  + util:
  - Remove unused function.
  - Add utility to parse /etc/shells.
  + gterminal: Fix completion argument parsing.
  + server:
  - Stay around a bit after last window closes.
  - Exit on unsupported locale.
  - Simplify deprecated object property warning suppression
    (bgo#749195).
  + build:
  - Update macros from upstream.
  - Fix config.h include order.
  - Use stable versions.
  - Define min/max required/allowed glib and gtk+ versions.
  + screen:
  - Get process arguments without /proc on FreeBSD and OpenBSD.
  - Update colors at the right spot (bgo#746425).
  + Add new keyword 'cmd' to .desktop (bgo#749239).
  + profile: editor: Make the profile preferences a GtkWindow.
  + prefs:
  - Make profile editors not transient.
  - Make the preferences a GtkWindow (bgo#748342).
  + client: legacy: Fall back to default profile (bgo#747106).
  + profile: prefs: Remove update-records pref.
  + Updated translations.
* Mon May 11 2015 dimstar@opensuse.org
- Update to version 3.16.2:
  + Bump vte dependency.
  + Updated translations.
* Tue Apr 14 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Make the ActiveTerminal field in the config file format work.
  + client: legacy: Fall back to default profile (bgo#747106).
  + Updated translations.
* Thu Mar 26 2015 zaitor@opensuse.org
- Add gnome-terminal-dark-theme.patch: Allow gnome-terminal to have
  dark theme preferance.
- Add libtool BuildRequires and call autoreconf as the above patch
  touches the buildsystem.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + client: let DISPLAY flow through (bgo#746358).
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Bugs fixed: bgo#685742, bgo#733210, bgo#735242.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + tab-label: Rely on new GTK+ API to center the label
    (bgo#743663).
  + profile: Remove the "Command" sub-heading (bgo#744327).
  + gterminal: Add more profile functions: allow adding, removing
    and cloning a profile.
  + window: Add tab position setting (bgo#75420#c25).
  + Bugs fixed: bgo#739410, bgo#730632, bgo#743395. bgo#743663,
    bgo#742304.
  + Updated translations.
- Rebase gnome-terminal-transparency.patch.
* Thu Feb 12 2015 zaitor@opensuse.org
- Update to version 3.15.0:
  + notebook: Make tabs nondetachable.
  + window:
  - Focus the terminal if only a single tab remains in a
    window (bgo#742422).
  - window: Update size on tab title change (bgo#732588).
  + Remove dark theme pref (bgo#707206, bgo#742040, bgo#742333,
    bgo#649358).
  + screen: Fix crash with empty child process command line
    (bgo#742560).
  + help:
  - Update desc for text selection (bgo#742304).
  - Fix window theme pref instructions (bgo#742040).
  - fix tab/window pref instructions (bgo#742119).
  + build: Use portable shell in configure.ac.
  + client: Hide obsolete --title option. Accept it for
    compatibility, but ignore it (bgo#740188).
  + server:
  - Sanitise the environment.
  - Reorder atfork/setrlimit calls.
  - Increase RLIMIT_NOFILE to the maximum allowed (bgo#646098).
  + Updated translations.
- Drop gnome-terminal-fix-crash.patch: fixed upstream.
- Rebase gnome-terminal-transparency.patch.
* Thu Feb 12 2015 dimstar@opensuse.org
- Add gnome-terminal-fix-crash.patch: Fix crash with empty child
  process command line (bgo#742560).
- Add gnome-terminal-transparency.patch: Allow gnome-terminal to be
  set to transparent.
- Add gnome-terminal-transparency-fix-for-broken-themes.patch:
  Ensure that the window itself always has a background. Some
  themes don't specify a widget background color.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Remove word-chars setting help (bgo#727774).
  + Updated translations.
* Sun Sep 14 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + help:
  - Review pref-scrolling.
  - Add ambiguous character width (bgo#727555).
  - Document encodings per profile (bgo#727555).
  + Flag gnome-terminal as a multiple-window app (bgo#735484).
  + Allow disabling shortcuts (bgo#731933).
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Profile settings UI update.
  + Updated translations.
* Wed Jul 16 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Bugs fixed: bgo#730850, bgo#730389, bgo#730936, bgo#731998.
- Changes from version 3.13.1:
  + Bugs fixed: bgo#724110, bgo#729394, bgo#729597, bgo#730390,
    bgo#730498, bgo#730389.
  + Updated translations.
- Add vala BuildRequires: new dependency.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.13.0:
  + Work with new vte 2.91 API.
  + Bug fixes and improvements.
  + Updated translations.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Important bug fixes.
  + Bug fixes.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + window: Fix parent class in template definition.
  + Fix su/sudo detection.
  + Updated translations.
* Thu May  1 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix shortcut key disabling (bgo#728121).
  + Fix app menu New Terminal item (bgo#726942).
  + Updated documentations.
  + Updated translations.
* Thu Apr 10 2014 mgorse@suse.com
- Add
  0001-build-Add-cleanup-functions.patch,
  0001-all-Do-not-use-s-format-with-g_variant_get.patch,
  0001-profile-Fix-dummy-settings-patch.patch,
  0001-utils-Fix-double-free-in-error-path.patch: fixes for crashes
  from upstream (bgo#708198, bgo#724264).
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Build fixes.
  + Docs fixes (bgo#725252).
  + Add appdata file (bgo#708448).
  + Updated translations.
- Add appdata-tools BuildRequires: new dependency to validate the
  appdata files.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.3:
  + terminal-app: Use correct variable for search provider.
  + Updated translations.
- Add gnome-shell BuildRequires: Needed to build search provider.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.2:
  + client: legacy: We use application IDs instead of bus names.
  + terminal-nautilus: initiate ssh with -t.
  + all: Do not use '&s' format with g_variant_get.
  + screen:
  - Fix word-chars setting.
  - Allow getting the name of the current foreground process.
  - Allow man: links containing hyphens.
  - Add API to map UUIDs to screens.
  - container:
    . Use a GtkOverlay for the info bar.
    . Remove scrolled window code.
    . Fix parent class.
  + profile: Add rewrap-on-resize.
  + build:
  - Drop support for dconf 0.12.
  - help: Use no-lc-dist yelp.
  + server: Add a search provider.
  + app: Add setting to disable shell integration.
  + accels: Add find items to accel editor.
  + Remove last bits of GTK_STOCK.
  + Replace deprecated mallard markup and namespace.
  + Updated translations.
- Create new subpackage gnome-shell-search-provider-gnome-terminal,
  containing the new GNOME Shell search provider.
* Wed Nov 20 2013 dimstar@opensuse.org
- Update to version 3.11.0:
  + Build fixes.
  + Code cleanup.
  + Let applications handle clicks in mouse tracking mode
    (bgo#13299).
  + Remove 'visible when necessary' pref value (bgo#712331).
  + Documentation fixes (bgo#711164).
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Minor bugfixes.
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Remove UUID from profile list display (bgo#704097).
  + Remove input method submenu from context menu.
  + Make terminal close keybinding work for single tab windows
    (bgo#701354).
  + Fix a crash while waiting for clipboard data (rh#977010).
  + Fix output of --disable-factory option (bgo#707899).
  + Fix desktop file categories (bgo#707552).
  + Misc bug and build fixes.
  + Updated translations.
- Pass --with-nautilus-extension to configure: the extensions is
  now disabled by default, but we keep on providing it in a sep.
  package.
* Mon Jul 29 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Build fixes and cleanup.
  + Portability fixes.
  + Migration fixes.
  + Enable menu access key by default again.
  + Enable nautilus extension by default.
  + Remove input method submenu from context menu.
  + Add Quit and New Terminal items to app menu.
  + Implement dark theme checkbox in preferences.
  + Unify new tab and new window.
  + Updated translations.
- No longer delete various languages for openSUSE <= 11.2.
- Pass --disable-static to configure: we only care for dynamic
  stuff.
- Create new subpackage nautilus-extension-terminal with the
  extension for nautilus. Obsolete the former
  nautilus-open-terminal from this new package (source was imported
  into the main tree and renamed on the go).
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.8.4:
  + Fix a crash on session resume (rh#981440).
  + Fix a mem leak.
  + Don't write to gsettings on each startup if migration is
    disabled.
  + Updated translations.
* Sun Jun 16 2013 zaitor@opensuse.org
- Update to version 3.8.3:
  + Reduce environmental pollution.
  + Critical bug fixes: rh#966713, rh#968140.
  + Bug fixes: bgo#640727.
  + Updated translations.
- Stop passing obsolete --disable-schemas-install and
  - -disable-scrollkeeper to configure.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Misc fixes.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Nautilus extension fixes (bgo#697225 and others).
  + Portability fix (bgo#697024).
  + Updated translations.
* Mon Apr  1 2013 dimstar@opensuse.org
- Update to version 3.8.0.1:
  + accels: Add more accel-able tabs (bgo#696123).
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Bug fixes.
  + Updated translations.
* Sun Mar 17 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Bug fixes.
  + Bugs fixed: bgo#695759, bgo#695569, bgo#695571, bgo#695369,
    rh#919715.
  + Updated translations.
* Mon Mar  4 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Rewritten help in mallard.
  + Bug fixes.
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Bugs fixed: bgo#691931, bgo#691932, bgo#692021, bgo#691997,
    bgo#692055, bgo#692148.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + GConf->GSettings migration fixes.
  + Keybindings fixes.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.0:
  + Terminal now uses GSettings and DConf instead of GConf. The
    existing profiles and settings will be automatically migrated
    from GConf when first running this version.
  + To make new tabs opened within Terminal have the same working
    directory as the current tab, it is necessary for the shell
    running in the terminal to cooperate. For this, vte installs a
    bash shell script that you must use in your bash PS1 prompt.
    For example, you can put this at the end of your ~/.bashrc:
    export PS1='\[$(__vte_ps1)\]'$PS1
  + Many bugs fixed.
  + Updated translations.
- Add pkgcondif(dconf) BuildRequires following upstreams port to
  GSettings. Note: pkgconfig(gconf-2.0) is needed for the GConf to
  DConf migration helper tool.
- Replace pkgconfig(sm) and pkgconfig(ice) BuildRequires with
  pkgconfig(libnautilus-extension), following upstreams changes.
- Add pkgconfig(uuid) BuildRequires: new dependency.
- Add pkgconfig(gio-2.0) BuildRequires so it can be versioned.
- Add gsettings schema handling macros to post/postun.
- Drop gnome-doc-utils-devel BuildRequires: it's no longer needed.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix opening http-less URLs (bgo#685599).
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated documentation
  + Updated translations.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Port to new documentation infrastructure
  + screen: Recognise man: and info: URIs
  + Bugs fixed: bgo#676452
  + Updated translations.
- Add yelp-tools BuildRequires, following upstreams port to the new
  documentation infrastructure (note: gnome-doc-utils-devel should
  no longer be needed, but configure still checks for it).
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1.1:
  + No changes.
- Changes from version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + No changes.
- Changes from version 3.4.0:
  + Use symbolic icon for the close button.
  + Adapt for scroll changes in GTK+ 3.4.
  + Updated translations.
* Sun Feb 19 2012 dimstar@opensuse.org
- Add pkgconfig(ice), pkgconfig(sm) and pkgconfig(x11)
  BuildRequires: this used to be pulled in by something else
  before, but the relayout of xorg-x11 packages changed that.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.0:
  + Add default encoding profile property (bgo#108711)
  + Works with gtk+ broadway backend
  + Updated translations.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Drop GTK 2 support.
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + bgo#647077: Use gsettings for proxy settings.
  + Updated translations.
* Wed Apr 27 2011 vuntz@opensuse.org
- Remove now unneeded dbus-1-glib-devel, scrollkeeper,
  startup-notification-devel BuildRequires.
- Change gconf2-devel BuildRequires to pkgconfig(gconf-2.0).
- Add explicit pkgconfig() BuildRequires: glib-2.0, gtk+-3.0.
- Drop our copy of gtk-builder-convert:
  + Remove the source file.
  + Remove python-xml BuildRequires.
  + Do not set GTK_BUILDER_CONVERT on build.
  + Add gtk2-devel BuildRequires, which has the script.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Update paste sensitivity whenever clipboard changes
  + Updated translations.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 2.33.90:
  + Disable sorting in the Keyboard Shortcut editor
  + Take system font from gsettings instead of gconf
  + Theme close button
  + Updated translations.
- Changes from version 2.33.5:
  + More port to gtk3
  + Misc fixes.
  + Updated translations.
- Changes from version 2.33.4:
  + More port to gtk3
  + Updated translations.
- Changes from version 2.33.3:
  + Remove S/Key support
  + More port to gtk3
  + Updated translations.
- Changes from version 2.33.2:
  + Do not put TERM in the spawn env
  + More port to gtk3
  + Don't crash when receiving bogus data in dbus call
  + Updated translations.
- Changes from version 2.33.1:
  + Make geometry parsing more robust
  + Implement a better fix for wrong sizing of detached tabs
  + Fix gridding for small sizes
  + Port to gtk3
  + Updated translations
- Pass --with-gtk=3.0 to configure.
- Add copy of git gtk2 gtk-builder-convert to fix build and not
  rely on modified gtk2 packages, pass GTK_BUILDER_CONVERT varibale
  to configure call, and add python-xml BuildRequires.
- Change vte-devel BuildRequires to pkgconfig(vte-2.90)
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Don't crash when receiving bogus data in the dbus call
    (rh#650276)
  + Updated translations.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + bgo#630163: Set _NET_WM_DESKTOP on the new X window when
    handling composited-changed
  + Fix compiler warnings.
  + Updated translations.
- Drop gnome-terminal-desktop.patch and instead use
  %%suse_update_desktop_file to change the Name and GenericName.
- Update summary and description.
* Sun Aug 29 2010 dimstar@opensuse.org
- Update to version 2.31.91:
  + bgo#627776: Do resume when starting the factory
  + bgo#627258: Adjust find dialogue spacing and packgings
  + bgo#627133: Bump gtk3 req to 2.90.6
  + Updated translations.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Relicensed under GPLv3
  + Translation updates.
- Update License tag to "GPLv3+; LGPLv2.1+".
* Thu Jul  8 2010 dimstar@opensuse.org
- Update to version 2.31.3:
  + bgo#618188: edit profiles dialog in docs
  + bgo#612712: Fix most of the GSEAL issues
- Changes from version 2.31.2:
  + Fix build
- Changes from version 2.31.1:
  + Features:
  - bgo#78963: Add a Search menu
  - Enable "File -> Save Contents" again
  - Show an info-bar if failed to execute command
  - bgo#607875: Add "Use custom default terminal size" profile
    setting
  + bgo#521193: Closing tabs regression fixed
  + bgo#521417: Fix compiler warnings
  + bgo#614464: Escape ":", "@" or "/" chars within proxy
    user/password env vars
  + Updated translations.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Don't apply the default size (bgo#607875)
  + Hide the Save Contents menu entry
  + Updated translations.
* Thu Mar 11 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Many bugs fixed: http://bugzilla.gnome.org/buglist.cgi?product=gnome-terminal&bug_status=RESOLVED&resolution=FIXED&chfieldfrom=2009-09-24&chfieldto=2010-03-29+23:59:00&chfield=bug_status
  + Many translation updates.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.29.6:
  + Add "Save Contents" menu item
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 2.29.5:
  + Use gtk_widget_is_toplevel() instead of GTK_WIDGET_TOPLEVEL
    (bgo#606298)
  + Add ctrl-shift-up/down documentation (bgo#602004)
  + Translation updates
* Wed Dec 23 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + --geometry works again
  + Tab detaching works again
  + Unlimited scrollback
  + Improved proxy env suppport
  + Bold color support
  + Updated translations.
* Tue Dec 15 2009 vuntz@opensuse.org
- Update to version 2.28.2:
  + Updated translations.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Plug leak.
  + Updated translations.
* Fri Sep 25 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed Sep  9 2009 lmedinas@opensuse.org
- Update to version 2.27.92:
  + bgo#500563 - Update to GNOME Help Centre OMF Files for "Issue
    24: Documentation Meta-data" of GNOME's GHOP Contest
  + bgo#553357 - Options in drop down boxes are not translated
  + bgo#564648 - when switching to/from compositing enabled, windows
    appear as new
  + bgo#565328 - Factory prevents unmounting of device
  + bgo#566335 - No obvious way to leave fullscreen
  + bgo#571002 - URL linking also selects trailing dot.
  + bgo#573279 - Accelerator for "Cancel" and "Close this window"
    in close dialog is the same
  + bgo#574207 - Missing translator comment
  + bgo#574776 - gnome-terminal crashed with SIGSEGV in
    gtk_menu_shell_select_first()
  + bgo#575295 - Question-button label mismatch in the closing
    dialog
  + bgo#575308 - Make gnome-terminal session loading work
  + bgo#576675 - gnome terminal treats pixelsized fonts point sized
  + bgo#577025 - Use of uninitialized variables
  + bgo#577313 - gnome-terminal crashed with SIGSEGV in
    gtk_ui_manager_remove_ui()
  + bgo#582861 - Tango profile black color is not black
  + bgo#583690 - Setting keyboard shortcuts via mandatory gconf
    settings no longer works
  + bgo#584943 - Creating new profile results in grayed out
    preferences on first view
  + bgo#586308 - annoying session-saving misbehaviour
  + bgo#587305 - wrong path in generated file
  + bgo#590885 - possible typo
  + bgo#590952 - gnome-terminal can't discriminate between shell
    and commands anymore
  + bgo#594025 - crash in Terminal: running cat /dev/urandom
  + Translation updates.
* Thu Aug 20 2009 dimstar@opensuse.org
- Update to version 2.27.91:
  + bgo#575308 - Make gnome-terminal session loading work
  + bgo#561663 - gnome-terminal crashes when gconf isn't set up
    correctly
  + bgo#572549 - Memory corruption in gnome-terminal
  + bgo#574776 - gnome-terminal crashed with SIGSEGV
    in gtk_menu_shell_select_first()
  + bgo#576675 - gnome terminal treats pixelsized fonts point sized
  + bgo#583690 - Setting keyboard shortcuts via mandatory gconf
    settings no longer works
  + bgo#586308 - annoying session-saving misbehaviour
  + bgo#590952 - gnome-terminal can't discriminate between shell
    and commands anymore
  + Translation updates.
* Tue Aug  4 2009 vuntz@novell.com
- Do not package omf files twice.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.26.3.1:
  + Build fix.
- Changes from version 2.26.3:
  + Try keeping the icon title in sync with the real title
  + Fix various issues when enabling/disabling a compositing
    manager (bgo#564648)
  + Print "Close this window?" only if more than one tab would be
    closed (bgo#575295)
  + Fix profile editor on new profile being greyed out (bgo#584943)
  + Misc fixes.
  + Updated translations.
* Tue May 19 2009 vuntz@novell.com
- Update to version 2.26.2:
  + Updated translations.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + bgo#500563: Update to GNOME Help Centre OMF Files
  + bgo#574207: Missing translator comment
  + bgo#575308: Make gnome-terminal session loading work
  + bgo#576675: gnome terminal treats pixelsized fonts point sized
  + bgo#577025: Use of uninitialized variables
  + bgo#577313: Fix crash
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 2.26.0:
  + bgo#570591: running 'reset' shrinks the terminal window.
  + bgo#572414: Close this terminal' warning labels button as
    'Close Window'
  + Fix possible gsize wraparound issue when demarshaling the data
  + Correct the pspec ID.
  + bgo#572549: Memory corruption in gnome-terminal.
  + Updated translations.
* Mon Mar  9 2009 vuntz@novell.com
- Remove -fno-strict-aliasing from CFLAGS.
- Do not add DocPath to desktop file: it's not needed by yelp.
* Tue Feb 17 2009 mboman@suse.de
- Update to version 2.25.91:
  + Translation updates
- Remove docbook_4, gnome-common, gnutls-devel, libglade2-devel,
  libgnomeprintui-devel, libwnck-devel, perl-XML-Parser,
  scrollkeeper from BuildRequires
- Add gconf2-devel, dbus-1-glib-devel to BuildRequires
* Tue Feb 10 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Sun Feb  1 2009 mboman@suse.de
- Update to version 2.25.5:
  + Break out of the loop once the work's done.
  + Call g_thread_init(). bgo#565516
  + chdir() to /home/chpe in the factory process, so we don't hog any
    mountpoints. bgo#565328
  + Reorder this conditional so we only get the RGBA colourmap if
    compositing is enabled.
  + bgo#506686 – could be smarter when parsing parenthesis
    (for URL construction)
  + Set the default keybindings also in the table in the code. Fixes accels
    with borked GConf; part of bgo#564649.
  + Translation updates
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec 20 2008 mboman@suse.de
- Update to version 2.25.3:
  + Libbonobo dependency dropped
  + Libgnome and libgnomeui dependency dropped
  + Depends on VTE 0.19
  + Now uses DBus for single instance/factory setup
  + Many bugs fixed
  + Translation updates
* Sat Dec  6 2008 mauro@suse.de 
- Updated translations.
* Thu Oct 23 2008 maw@suse.de
- Update to version 2.24.1.1:
  + Revert the fix for bgo#548600 because it causes a regression.
* Wed Oct 22 2008 mboman@suse.de
- Update to version 2.24.1:
  + Bugs fixed: bgo#552952, bgo#453193, bgo#548388, bgo#548600
    bgo#554485, bgo#555824, bgo#552938, bgo#552943, bgo#552950
    bgo#553512
  + Translation updates
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Bug fixed: bgo#553111
  + Updated translations
- Respin gnome-terminal-desktop.patch.
* Mon Sep  1 2008 mboman@novell.com
- Update to version 2.23.91:
  + Bugs fixed: bgo#549308, bgo#399744, bgo#401547, bgo#151794,
    bgo#519191
  + Plug a mem leak.
  + Don't try to g_strfreev something we don't own.
  + Make the terminal window's role distinct from other g-t window's role,
    to be able to match just them with devilspie.
  + Use a static window role for the single instance encodings dialogue.
  + Updated translations.
* Tue Aug  5 2008 captain.magnus@opensuse.org
- Update to version 2.23.6:
  + g_listenv returns only the env var names, not name=value pairs.
  + Translation updates
* Wed Jun 25 2008 maw@suse.de
- Update to version 2.23.4.2:
  + Bugs fixed: bgo#536463, bgo#528683, bgo#418192, bgo#537112,
    bgo#537888, bgo#536899, bgo#537215, bgo#536639, bgo#538809,
    brc450808, and brc#450979
- Drop the following upstreamed patch:
  gnome-terminal-2.18.1-correct-help-uri.patch.
* Mon May  5 2008 jpr@suse.de
- Remove gnome-terminal-force-terminal-draw.patch, it was fixed
  in a different way upstream, see bgo #338913
- Remove gnome-terminal-uninited-vars.patch, the simple font
  selector it applied against was removed
* Fri Apr 11 2008 maw@suse.de
- Update to version 2.22.1:
  + Bugs fixed: bgo#521193 and bgo#521417.
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Updated translations.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Ensure menu items are always drawn
  + Stop forcing invisible_char to *
  + Updated translations.
* Wed Feb 20 2008 maw@suse.de
- Update to version 2.21.91.1:
  + Adapt to new GChecksum API
  + Fix cropped tab close buttons when using recent versions of
    gnome-icon-theme
  + Fix for bgo#336155
  + Updated translations
- Respin gnome-terminal-defaults.patch and
  gnome-terminal-desktop.patch.
* Wed Jan 30 2008 rodrigo@suse.de
- Update to version 2.21.90:
  * Use the gtk-cursor-blink setting and remove the profile option
  * Remove extra frame from profile editor
  * Use G_STRFUNC instead of the deprecated G_GNUC_FUNCTION
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Wed Sep 19 2007 sbrabec@suse.cz
- Updated to version 2.18.2:
  * license confusion fix
  * documentation migrated to gnome-doc-utils
  * use Tango terminal color scheme by default
* Sat Sep 15 2007 hpj@suse.de
- Add gnome-terminal-2.18.1-correct-help-uri.patch so we can find
  our help files correctly.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Tue Jul 10 2007 maw@suse.de
- Update to version 2.18.1
- Several crashes fixed.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Thu Apr 12 2007 maw@suse.de
- Update to version 2.18.0
- Fixes for bugzilla.gnome.org #412733 and #410281.
* Fri Mar  9 2007 maw@suse.de
- Update to version 2.17.91
  - Plug a memory leak.
  - Do not disable some keybindings when DnDing notebook pages.
  - Include the Tango color scheme.
  - Remember the zoom setting for new tabs.
  - Do not have clashing shortcuts in popups.
  - Do not resize when switching between tabs, hopefully.
  - Focus new terminals when they are created, always.
  - Handle long terminal titles better.
  - Do not paint initially terminals black.
  - Various UI updates and inconsistencies eliminated.
  - A few crashes fixed.
- Remove upstreamed gnome-terminal-tab_resize_fix_r2082.patch
* Mon Feb 26 2007 sbrabec@suse.cz
- Fixed invalid window resize (#211443).
* Wed Jan 17 2007 sbrabec@suse.cz
- Removed obsolete scrollkeeper directory (#230786).
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
* Fri Dec 15 2006 maw@suse.de
- Move to /usr.
* Fri Oct 13 2006 danw@suse.de
- Remove dead patch
* Fri Oct 13 2006 jhargadon@suse.de
- added gnome-doc-utils-devel in BuildRequires.
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- Honours the --title switch
- Fixes a couples of memory leaks
- New and updated translations
* Mon Oct  2 2006 oswerkstrom@suse.de
- Bug 177355 - gnome-terminal --title command ignored.
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- Bug 354056 – Build broken: missing help/fr/Makefile.am
- Bug 351319 – crash on Terminal
- Part of Bug 352873 – crash in Terminal: Edit current profile aft...
- Bug 353020 – Detaching a tab does not preserve the size
- Bug 336943 – Critical warning and crash in gnome-terminal
- Bug 138609 – Next/prev TAB keybindings should not be passed through
  on  first/last tab
- Fix intltool req.
* Mon Aug 21 2006 jhargadon@suse.de
- update to version 2.15.4
- Bug 349459 – does not assert dependency on gdk 2.10
- Bug 85926 – dnd'd filenames should be escaped
- Bug 324426 – Open/close tab adds row to terminal
- Bug 336947 – [patch] Redundant vte_terminal_set_font_full() calls
- Use real transparency when it's available
- Improve the dialog to ask for confirmation when closing a window
  with more than one tab open
- Migrated to gnome-doc-utils
- Exports authentication proxy settings
- Fixes the close button of the about dialog
- Includes final slashes on URL highlighting
- Eliminates superfluous resize on drag-n-drop
- updates to translations
* Tue Mar  7 2006 gekker@suse.de
- Disable menu accelerators by default (#143086)
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Fri Feb 17 2006 sreeves@suse.de
- Update .desktop file (Name, GenericName, Comment, DocPath)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Sep  6 2005 jpr@suse.de
- Update to version 2.12.0
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.3
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.2
* Fri Jul 22 2005 gekker@suse.de
- Update to version 2.11.1
- Fix uninitialized variables
* Tue Mar 22 2005 sbrabec@suse.cz
- Reverted TERM to xterm (#73798).
* Wed Mar 16 2005 clahey@suse.de
- Change desktop Name to Gnome Terminal.
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- update version to 2.9.3
* Thu Jan 20 2005 gekker@suse.de
- Update version to 2.9.2
* Thu Nov 25 2004 ro@suse.de
- added suse_update_desktop_file
* Mon Nov 22 2004 sbrabec@suse.cz
- Set TERM=gnome. It fixes screen garbling in mutt (#43189).
* Tue Nov  2 2004 ro@suse.de
- locale rename: no -> nb
* Fri Aug 27 2004 clahey@suse.de
- Cache gnome-terminal help and show gnome-terminal in khelpcenter.
* Wed May 12 2004 clahey@suse.de
- Upgraded to 2.6.0.
- Upgraded patches.
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Wed Feb 25 2004 hhetter@suse.de
- remove schema patch, obsoleted by new one
- include gnome-terminal-defaults.patch: don't use
  system font, don't use mnemonics in the menubar
* Mon Feb 16 2004 hhetter@suse.de
- install schemas in %%post and %%postun
* Sat Jan 10 2004 adrian@suse.de
- fix build as user
* Tue Nov 11 2003 hhetter@suse.de
- updated to version 2.4.2
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.
* Mon Sep 29 2003 hhetter@suse.de
- updated to version 2.4.0.1 [GNOME2.4]
* Mon Sep 22 2003 sbrabec@suse.cz
- Obsolete gnome-core (bug #31480),
* Mon Sep  8 2003 sbrabec@suse.cz
- Use RPM_OPT_FLAGS.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jun 30 2003 sbrabec@suse.cz
- Updated to version 2.2.2.
- Clean-up of neededforbuild.
* Sun Jun 29 2003 ro@suse.de
- use gnome2-devel-packages in neededforbuild
- use find_lang
- added directories to filelist
* Wed Feb 12 2003 hhetter@suse.de
- don't used font size from system fonts but use
  the font specified in the schema file for the
  default profile
* Tue Jan 28 2003 hhetter@suse.de
- updated to version 2.2.0
- fix kde datadir
* Thu Jan 16 2003 sbrabec@suse.cz
- Added libjpeg to neededforbuild.
* Thu Nov 28 2002 hhetter@suse.de
- updated to version 2.0.2 [GNOME 2.0.3]
- removed crash-on-restore.dif as it is upstream
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Fri Sep 13 2002 sbrabec@suse.cz
- updated to version 2.0.1
- Fix for crash on session restore (post-2.0.1 fix from CVS).
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Tue Jun 18 2002 hhetter@suse.de
- fix schema file install
* Sun Jun 16 2002 ro@suse.de
- use libpng-devel-packages in neededforbuild
* Fri Jun 14 2002 hhetter@suse.de
- updated to version 2.0.0
- provide schema file
* Wed Jun  5 2002 hhetter@suse.de
- initial SuSE Release 1.9.7
